# Others

## 相关项目

这是与stagesep系列的迭代过程，不出意外的话，x将会是长期维护版本。

- [stagesep2](https://github.com/williamfzc/stagesep2)
- [stagesep (deprecated)](https://github.com/williamfzc/stagesep)

具体可以阅读：https://testerhome.com/topics/19978

## Bug 报告

可想而知的，要考虑到所有的场景是非常困难的，在项目前期很难做到。如果你怀疑遇到bug，建议先更新到最新版本再尝试：`pip install --upgrade stagesepx`。如果问题依旧存在，请通过issue反馈。

有什么建议或者遇到问题可以通过 issue 反馈给我。

## 贡献代码 或 加入我们

欢迎开发者为这个项目贡献内容。在开始前，最好将你的想法通过 issue 贴出来，因为很可能你的想法已经处于开发中了 ：）

你也可以通过 [issue面板](https://github.com/williamfzc/stagesepx/issues) 了解该项目近期的开发内容，所有的新特性都会先同步到上面。

## 联系方式

- 如果你有疑问与建议，在不涉密的前提下请**尽量通过 issue 方式反馈**。你的疑问与建议很可能能够帮助其他遇到相似状况的人。
- fengzc@vip.qq.com

## License

[MIT](https://github.com/williamfzc/stagesepx/blob/master/LICENSE)
